Skip to content

Commit e31e9c9

Browse files
author
MFC Action
committed
Docs @ 54aa379
1 parent d5166c8 commit e31e9c9

129 files changed

Lines changed: 11692 additions & 11411 deletions

File tree

Some content is hidden

Large Commits have some content hidden by default. Use the searchbox below for content that may be hidden.

documentation/architecture.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -427,7 +427,7 @@ <h1 class="doxsection"><a class="anchor" id="autotoc_md13"></a>
427427
<li><b>Add the module to <span class="tt">docs/module_categories.json</span></b> so it appears in this page</li>
428428
</ol>
429429
<p>Follow the pattern of existing modules like <span class="tt">m_body_forces</span> (simple) or <span class="tt">m_viscous</span> (more involved) as a template.</p>
430-
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
430+
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
431431
</div><!-- PageDoc -->
432432
</div><!-- doc-content -->
433433
<div id="page-nav" class="page-nav-panel">

documentation/case.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -342,7 +342,7 @@ <h3 class="doxsection"><a class="anchor" id="sec-patches"></a>
342342
<td class="markdownTableBodyRight"><span class="tt">model_id</span> </td><td class="markdownTableBodyCenter">Integer </td><td class="markdownTableBodyCenter">Not Supported </td><td class="markdownTableBodyLeft">Index into the <span class="tt">stl_models</span> array (geometry 21) </td></tr>
343343
</table>
344344
<p>*: These parameters should be prepended with <span class="tt">patch_icpp(j)%</span> where $j$ is the patch index.</p>
345-
<p>The Table lists the patch parameters. The parameters define the geometries and physical parameters of fluid components (patch) in the domain at initial condition. Note that the domain must be fully filled with patche(s). The code outputs error messages when an empty region is left in the domain.</p>
345+
<p>The Table lists the patch parameters. The parameters define the geometries and physical parameters of fluid components (patch) in the domain at initial condition. Note that the domain must be fully filled with patches. The code outputs error messages when an empty region is left in the domain.</p>
346346
<ul>
347347
<li><span class="tt">tau_e(i)</span> is the <span class="tt">i</span>-th component of the elastic stress tensor, ordered as <span class="tt">tau_xx</span>, <span class="tt">tau_xy</span>, <span class="tt">tau_yy</span>, <span class="tt">tau_xz</span>, <span class="tt">tau_yz</span>, and <span class="tt">tau_zz</span>. 1D simulation requires <span class="tt">tau(1)</span>, 2D <span class="tt">tau(1:3)</span>, and 3D <span class="tt">tau(1:6)</span>.</li>
348348
</ul>

documentation/case_constraints.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -1462,7 +1462,7 @@ <h2 class="doxsection"><a class="anchor" id="physics-warnings"></a>
14621462
</table>
14631463
<hr />
14641464
<p>💡 <b>Tip:</b> If you encounter a validation error, check the relevant section above or review <a href="https://github.com/MFlowCode/MFC/blob/master/toolchain/mfc/case_validator.py"><span class="tt">case_validator.py</span></a> for complete validation logic.</p>
1465-
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
1465+
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
14661466
</div><!-- PageDoc -->
14671467
</div><!-- doc-content -->
14681468
<div id="page-nav" class="page-nav-panel">

documentation/cli-reference.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -999,7 +999,7 @@ <h3 class="doxsection"><a class="anchor" id="autotoc_md81"></a>
999999
<h3 class="doxsection"><a class="anchor" id="autotoc_md82"></a>
10001000
Debug Logging (<span class="tt">-d, --debug-log</span>)</h3>
10011001
<p>Enables debug logging for the Python toolchain (mfc.sh internals). This is for troubleshooting the build system, not the MFC simulation code.</p>
1002-
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
1002+
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
10031003
</div><!-- PageDoc -->
10041004
</div><!-- doc-content -->
10051005
<div id="page-nav" class="page-nav-panel">

documentation/examples.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -630,7 +630,7 @@ <h3 class="doxsection"><a class="anchor" id="autotoc_md313"></a>
630630
<p><img src="result-2D_shockdroplet-example.png" alt="" height="400" class="inline"/></p>
631631
<p>This example case contains an automated convergence test using a 1D, two-component advection case. The case can be run by executing the bash script <span class="tt">./submitJobs.sh</span> in a terminal after enabling execution permissions with <span class="tt">chmod +x ./submitJobs.sh</span> and setting the <span class="tt">ROOT_DIR</span> and <span class="tt">MFC_DIR</span> variables. By default the script runs the case for 6 different grid resolutions with 1st, 3rd, and 5th, order spatial reconstructions. These settings can be modified by editing the variables at the top of the script. You can also run different model equations by setting the <span class="tt">ME</span> variable and different Riemann solvers by setting the <span class="tt">RS</span> variable.</p>
632632
<p>Once the simulations have been run, you can generate convergence plots with matplotlib by running <span class="tt">python3 plot.py</span> in a terminal. This will generate plots of the L1, L2, and Linf error norms and save the results to <span class="tt">errors.csv</span>.</p>
633-
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
633+
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
634634
</div><!-- PageDoc -->
635635
</div><!-- doc-content -->
636636
<div id="page-nav" class="page-nav-panel">

documentation/parameters.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -1605,7 +1605,7 @@ <h2 class="doxsection"><a class="anchor" id="autotoc_md434"></a>
16051605
<div class="line"> </div>
16061606
<div class="line"># Filter by type</div>
16071607
<div class="line">./mfc.sh params -t real weno</div>
1608-
</div><!-- fragment --><div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
1608+
</div><!-- fragment --><div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
16091609
</div><!-- PageDoc -->
16101610
</div><!-- doc-content -->
16111611
<div id="page-nav" class="page-nav-panel">

documentation/physics_constraints.html

Lines changed: 1 addition & 1 deletion
Original file line numberDiff line numberDiff line change
@@ -656,7 +656,7 @@ <h3 class="doxsection"><a class="anchor" id="autotoc_md485"></a>
656656
<li>FFT WRT incompatible with cylindrical coordinates</li>
657657
<li>FFT WRT requires global dimensions divisible by 2</li>
658658
</ul>
659-
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-02</div> </div></div><!-- contents -->
659+
<div style="text-align:center; font-size:0.75rem; color:#888; padding:16px 0 0;">Page last updated: 2026-07-03</div> </div></div><!-- contents -->
660660
</div><!-- PageDoc -->
661661
</div><!-- doc-content -->
662662
<div id="page-nav" class="page-nav-panel">

post_process/doxygen_crawl.html

Lines changed: 3 additions & 3 deletions
Original file line numberDiff line numberDiff line change
@@ -523,6 +523,7 @@
523523
<a href="namespacem__global__parameters__common.html#a4724699cb454e5156bb55fa9a40c2855"/>
524524
<a href="namespacem__global__parameters__common.html#a4758b2b07114b4c029eb9f8617ce50fa"/>
525525
<a href="namespacem__global__parameters__common.html#a48a4499cdeb3b1aa64f38d08beec4fdd"/>
526+
<a href="namespacem__global__parameters__common.html#a4923fe1f16f7ad83c03fb4467458ae36"/>
526527
<a href="namespacem__global__parameters__common.html#a4cffac1ed73ae4fee589c4e8003f207f"/>
527528
<a href="namespacem__global__parameters__common.html#a4f2ed03f6c839071a4ca5c1dfcd1fbaf"/>
528529
<a href="namespacem__global__parameters__common.html#a4f8d4cb385eaa96d9f9e723361284809"/>
@@ -533,6 +534,7 @@
533534
<a href="namespacem__global__parameters__common.html#a53b6980a27274d0e743f7bc4de53bb80"/>
534535
<a href="namespacem__global__parameters__common.html#a54040a5b888b108d3cbbda7891f43d56"/>
535536
<a href="namespacem__global__parameters__common.html#a595208b31ab2930d4760238216f43c99"/>
537+
<a href="namespacem__global__parameters__common.html#a5f1c53c238890ef24c450a162fd9daa2"/>
536538
<a href="namespacem__global__parameters__common.html#a5f3a0e593971d4d6a5f953384ceab370"/>
537539
<a href="namespacem__global__parameters__common.html#a62c64a0319c9f3c309f353c29151adea"/>
538540
<a href="namespacem__global__parameters__common.html#a64d11fd6634dff139506a5b1ecd70a91"/>
@@ -548,6 +550,7 @@
548550
<a href="namespacem__global__parameters__common.html#a7cb80f5aac684da9d488cc0f5ec3f86c"/>
549551
<a href="namespacem__global__parameters__common.html#a80a963bfbdb8f497ff540a7b4beb6e75"/>
550552
<a href="namespacem__global__parameters__common.html#a80da2a9fb41a81d46cc23bb8e29bf480"/>
553+
<a href="namespacem__global__parameters__common.html#a83e5d0948853d981c6e1f20634c0376f"/>
551554
<a href="namespacem__global__parameters__common.html#a84ba917e04628adef4930a67e6396f41"/>
552555
<a href="namespacem__global__parameters__common.html#a8639a9fccbe089056a2a64d2ef72fb41"/>
553556
<a href="namespacem__global__parameters__common.html#a8698448318affdac440a7eb61a65d60f"/>
@@ -755,7 +758,6 @@
755758
<a href="namespacem__start__up.html#a236e81379b1a1a1d2bc5b8015d79ec9b"/>
756759
<a href="namespacem__start__up.html#a251f7304110b9e8a313fe4bb657291ce"/>
757760
<a href="namespacem__start__up.html#a2767103b12cf07614cd18dde1d7a21af"/>
758-
<a href="namespacem__start__up.html#a3a11331ef2de96000878ce4f160e2ba7"/>
759761
<a href="namespacem__start__up.html#a3dee31fb599d8ac0846990a2929979d3"/>
760762
<a href="namespacem__start__up.html#a43f2e386d1bd2f0f6212f31a97542b96"/>
761763
<a href="namespacem__start__up.html#a4a3d9f832e1e7fa3881dcdf3b948b8ba"/>
@@ -764,13 +766,11 @@
764766
<a href="namespacem__start__up.html#a5f4babcc7659bbc75924568ec03bc4e7"/>
765767
<a href="namespacem__start__up.html#a60defd7c59f932ace62e579943409087"/>
766768
<a href="namespacem__start__up.html#a70391523479940ba122a6dbec54a893a"/>
767-
<a href="namespacem__start__up.html#a737bb57c484cd1a82f53bfcd75061c98"/>
768769
<a href="namespacem__start__up.html#a742dab7988fbf7098faea99c924cfe74"/>
769770
<a href="namespacem__start__up.html#a7f5ea6cda966b32b91451d322615031e"/>
770771
<a href="namespacem__start__up.html#a826a3db02f160f0cf9ef541de5da0c8c"/>
771772
<a href="namespacem__start__up.html#a8511fa910551581e80da00df1bb0b894"/>
772773
<a href="namespacem__start__up.html#a8d9327774aa09798e954fe48fb02f0d5"/>
773-
<a href="namespacem__start__up.html#a9fe3c406193d18040691eabaa952d139"/>
774774
<a href="namespacem__start__up.html#aa595b91819077b36d6db5dab950120a8"/>
775775
<a href="namespacem__start__up.html#aaffd544e9ef13c1956f381e0eea73445"/>
776776
<a href="namespacem__start__up.html#abd393f15313d45fcada828eab6fbe405"/>

0 commit comments

Comments
 (0)